===================================================
🚀 mdapy - Molecular Dynamics Analysis with Python
===================================================

.. raw:: html

   <iframe src="https://mushroomfire.com/mdapy.html" height="200px" width="1000px", frameBorder="0"></iframe>

Overview
--------

**mdapy** provides a comprehensive suite of powerful, 
flexible, and straightforward tools for analyzing atomic 
trajectories generated from Molecular Dynamics (MD) simulations.


Dependencies
------------

* `numpy <https://numpy.org/>`_
* `polars <https://pola-rs.github.io/polars/>`_

Citation
---------
If you find **mdapy** useful, you can `star it! <https://github.com/mushroomfire/mdapy>`_
If you use **mdapy** in your scientific publications, please `cite the paper: <https://doi.org/10.1016/j.cpc.2023.108764>`_

.. code-block:: bibtex

   @article{mdapy023,
      title = {mdapy: A flexible and efficient analysis software for molecular dynamics simulations},
      journal = {Computer Physics Communications},
      pages = {108764},
      year = {2023},
      issn = {0010-4655},
      doi = {https://doi.org/10.1016/j.cpc.2023.108764},
      url = {https://www.sciencedirect.com/science/article/pii/S0010465523001091},
      author = {Yong-Chao Wu and Jian-Li Shao},
      keywords = {Simulation analysis, Molecular dynamics, Polycrystal, TaiChi, Parallel computing}
      }

Getting Started
-----------------
.. toctree::
   :maxdepth: 2
   
   gettingstarted/installation
   gettingstarted/atomic_structure_generation
   gettingstarted/use_mdapy_efficiently
   gettingstarted/phonon_calculation
   gettingstarted/load_save
   

Mdapy Python API
-----------------
.. toctree::
   :maxdepth: 2

   source/mdapy



